<!DOCTYPE html>
<html lang="zh-CN">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1">
    <title>script - client</title>
    <link rel="stylesheet" href="static/css/layui.css"/>
    <script src="static/layui.js"></script>
    <style type="text/css">
            html,body { height: 100%;margin: 0; padding: 0;}
    </style>

</head>
<body>
<ul class="layui-nav" lay-filter="">
    <li class="layui-nav-item layui-this" id="script"><a href="/">脚本管理</a></li>
    <li class="layui-nav-item" id="sys"><a href="/sys">系统管理</a></li>
    <li class="layui-nav-item" id="xyz"><a href="">XYZ</a></li>
</ul>
{%autoescape None%}
{% block one %}
{% end %}
</body>
</html>